@@ -12,6 +12,6 @@ func TestFunctionalOutputs(t *testing.T) {
 	RegisterFailHandler(Fail)
 
 	tc := "[Functional][Outputs][Multiple] Test Suite"
-	jr := reporters.NewJUnitReporter("/tmp/artifacts/junit/junit-functional-output.xml")
+	jr := reporters.NewJUnitReporter("/tmp/artifacts/junit/junit-functional-outputs-multiple.xml")
 	RunSpecsWithDefaultAndCustomReporters(t, tc, []Reporter{jr})
 }
