@@ -9,7 +9,7 @@ import (
 	"time"
 
 	logger "github.com/ViaQ/logerr/log"
-	"github.com/openshift/cluster-logging-operator/pkg/utils"
+	"github.com/openshift/cluster-logging-operator/internal/utils"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -33,7 +33,7 @@ type ContainerLog struct {
 	LogType          string                 `json:"log_type,omitempty"`
 	ViaqIndexName    string                 `json:"viaq_index_name"`
 	ViaqMsgID        string                 `json:"viaq_msg_id"`
-	Openshift        OpenshiftMeta          `json:"openshift"`
+	OpenshiftLabels  OpenshiftMeta          `json:"openshift"`
 	Structured       map[string]interface{} `json:"structured"`
 }
 
@@ -79,8 +79,7 @@ type PipelineMetadata struct {
 }
 
 type OpenshiftMeta struct {
-	Labels   map[string]string `json:"labels,omitempty"`
-	Sequence OptionalInt       `json:"sequence,omitempty"`
+	Labels map[string]string `json:"labels,omitempty"`
 }
 
 // Application Logs are container logs from all namespaces except "openshift" and "openshift-*" namespaces
@@ -195,7 +194,6 @@ type OVNAuditLog struct {
 	ViaqIndexName    string           `json:"viaq_index_name"`
 	ViaqMsgID        string           `json:"viaq_msg_id"`
 	Kubernetes       Kubernetes       `json:"kubernetes"`
-	Openshift        OpenshiftMeta    `json:"openshift"`
 	Level            string           `json:"level,omitempty"`
 }
 
@@ -361,11 +359,6 @@ func StrictlyParseLogs(in string, logs interface{}) error {
 
 type Logs []AllLog
 
-type PerfLog struct {
-	AllLog
-	Timing `json:",inline"`
-}
-
 type Timing struct {
 	//EpocIn is only added during benchmark testing
 	EpocIn float64 `json:"epoc_in,omitempty"`
@@ -373,12 +366,6 @@ type Timing struct {
 	EpocOut float64 `json:"epoc_out,omitempty"`
 }
 
-type PerfLogs []PerfLog
-
-func (t *PerfLog) ElapsedEpoc() float64 {
-	return t.EpocOut - t.EpocIn
-}
-
 //Bloat is the ratio of overall size / Message size
 func (l *AllLog) Bloat() float64 {
 	return float64(len(l.String())) / float64(len(l.Message))
